@extends('admin.layouts.app')

@section('panel')
    <div class="row">

        <div class="col-lg-12">
            <div class="card b-radius--10 ">
                <div class="card-body p-0">

                    <div class="table-responsive--sm table-responsive">
                        <table class="table table--light style--two">

                            <thead>
                                <tr>
                                    <th>@lang('Title')</th>
                                    <th>@lang('Url')</th>
                                    <th>@lang('Status')</th>
                                    <th>@lang('Clicked')</th>
                                    <th>@lang('Publication Status') </th>
                                    <th>@lang('Action')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse($ads as $data)
                                    <tr>
                                        <td>
                                            {{ strLimit(__($data->title), 40) }}
                                        </td>

                                        <td>
                                            {{ strLimit($data->url, 40) }}
                                        </td>

                                        <td>
                                            @if ($data->status == 1)
                                                <span class="badge badge--primary">@lang('Running')</span>
                                            @else
                                                <span class="badge badge--success">@lang('Completed')</span>
                                            @endif
                                        </td>

                                        <td>
                                            {{ $data->clicked }}
                                        </td>

                                        <td>
                                            @if ($data->publication_status == 1)
                                                <span class="badge badge--success">@lang('Published')</span>
                                            @else
                                                <span class="badge badge--danger">@lang('Unublished')</span>
                                            @endif
                                        </td>

                                        <td>
                                            <div class="button--group">
                                                @if ($data->status != 2)
                                                    <a class="btn btn-sm btn-outline--primary ms-1 editBtn" data-id="{{ $data->id }}" data-title="{{ $data->title }}" data-click="{{ getAmount($data->click) }}" data-credit="{{ getAmount($data->credit) }}" data-clicked="{{ getAmount($data->clicked) }}" data-url="{{ $data->url }}" data-publish="{{ $data->publication_status }}" data-image="{{ getImage(getFilePath('advertisement') . '/' . $data->image, getFileSize('advertisement')) }}"><i class="las la-pencil-alt"></i>@lang('Edit')
                                                    </a>
                                                @endif

                                                <button type="button" class="btn btn-sm btn-outline--danger confirmationBtn" data-action="{{ route('admin.ad.delete', $data->id) }}" data-question="@lang('Are you sure to delete this advertisement?')"><i class="las la-trash-alt"></i>@lang('Delete')</button>
                                            </div>
                                        </td>
                                    @empty
                                    <tr>
                                        <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                                    </tr>
                                @endforelse

                            </tbody>
                        </table><!-- table end -->
                    </div>
                </div>
                @if ($ads->hasPages())
                    <div class="card-footer py-4">
                        {{ paginateLinks($ads) }}
                    </div>
                @endif

            </div><!-- card end -->
        </div>
    </div>

    {{-- ADDMODAL METHOD MODAL --}}
    <div id="addModal" class="modal fade" tabindex="-1" role="dialog">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">@lang('Add Advertisement')</h5>
                    <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                        <i class="las la-times"></i>
                    </button>
                </div>
                <form action="{{ route('admin.ad.create') }}" method="POST" enctype="multipart/form-data">
                    @csrf
                    <div class="modal-body">
                        <div class="row">
                            <div class="col-lg-12 form-group">
                                <label for="name">@lang('Title')</label>
                                <input type="text" id="title" value="{{ old('title') }}" name="title" class="form-control" required>
                            </div>
                            <div class="col-lg-12 form-group">
                                <label for="name">@lang('Url') <code class="videoLinkExample"></code></label>
                                <input type="url" id="url" value="{{ old('url') }}" name="url" class="form-control" required>
                            </div>
                            <div class="col-lg-6 form-group">
                                <label for="credit">@lang('Expected click')</label>
                                <input type="number" name="click" value="{{ old('click') }}" id="click" class="form-control" min='1' required>
                            </div>
                            <div class="col-lg-6 form-group">
                                <label for="earn">@lang('Per click credit')</label>
                                <input type="number" name="credit" value="{{ old('credit') }}" id="credit" class="form-control" min='1' required>
                            </div>
                            <div class="col-lg-12 form-group">
                                <label>@lang('Publication Status') </label>
                                <input type="checkbox" data-width="100%" data-onstyle="-success" data-offstyle="-danger" data-bs-toggle="toggle" data-on="@lang('Published')" data-off="@lang('Unpublished')" name="publication_status">
                            </div>
                            <div class="col-lg-12">
                                <div class="image-upload">
                                    <div class="thumb">
                                        <x-image-uploader id="new" class="w-100" type="advertisement" :required=false />
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn h-45 w-100 btn--primary">@lang('Submit')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    {{-- EDIT METHOD MODAL --}}
    <div id="editModal" class="modal fade" tabindex="-1" role="dialog">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title"></h5>
                    <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                        <i class="las la-times"></i>
                    </button>
                </div>
                <form action="{{ route('admin.ad.edit') }}" method="POST" enctype="multipart/form-data">
                    @csrf
                    <input type="hidden" name="id">
                    <div class="modal-body">
                        <div class="row">
                            <div class="col-lg-12 form-group">
                                <label for="name">@lang('Title')</label>
                                <input type="text" value="{{ old('title') }}" name="title" class="form-control" required>
                            </div>
                            <div class="col-lg-12 form-group">
                                <label for="name">@lang('Url') <code class="videoLinkExample"></code></label>
                                <input type="url" value="{{ old('url') }}" name="url" class="form-control" required>
                            </div>
                            <div class="col-lg-12 form-group">
                                <label>@lang('Publication Status') </label>
                                <input type="checkbox" data-width="100%" data-onstyle="-success" data-offstyle="-danger" data-bs-toggle="toggle" data-on="@lang('Published')" data-off="@lang('Unpublished')" name="publication_status">
                            </div>
                            <div class="col-lg-12">
                                <div class="image-upload">
                                    <div class="thumb">
                                        <x-image-uploader id="update" class="w-100" type="advertisement" :required=false />

                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn h-45 w-100 btn--primary updateBtn">@lang('Submit')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection

@push('breadcrumb-plugins')
    <button type="button" class="btn btn-outline--primary btn-sm" data-bs-toggle="modal" data-bs-target="#addModal"><i class="las la-plus"></i>@lang('Add New')</button>
@endpush

@push('script')
    <script>
        (function($) {
            "use strict";

            $('.editBtn').on('click', function() {
                var modal = $('#editModal');
                modal.find('input[name=id]').val($(this).data('id'));
                modal.find('input[name=title]').val($(this).data('title'));
                modal.find('input[name=url]').val($(this).data('url'));
                modal.find('input[name=click]').val($(this).data('click'));
                modal.find('input[name=credit]').val($(this).data('credit'));
                modal.find('input[name=clicked]').val($(this).data('clicked'));
                modal.find('input[name=duration]').val($(this).data('duration'));
                modal.find('select[name=type]').val($(this).data('type'));
                modal.find('select[name=publication_status]').val($(this).data('publish'));
                modal.find('input[name=publication_status]').bootstrapToggle($(this).data('publish') == 1 ? 'on' : 'off');
                modal.find('.image-upload-preview').css({
                    "background-image": "url(" + $(this).data('image') + ")"
                });

                modal.modal('show');
            });

        })(jQuery);
    </script>
@endpush

@push('style')
    <style>
        /* Chrome, Safari, Edge, Opera */
        input::-webkit-outer-spin-button,
        input::-webkit-inner-spin-button {
            -webkit-appearance: none;
            margin: 0;
        }

        /* Firefox */
        input[type=number] {
            -moz-appearance: textfield;
        }

        .fileMargin {
            margin: -10px;
        }
    </style>
@endpush
