@extends('admin.layouts.app')

@section('panel')
    <div class="row">

        <div class="col-lg-12">
            <div class="card b-radius--10 ">
                <div class="card-body p-0">

                    <div class="table-responsive--sm table-responsive">
                        <table class="table table--light style--two">
                            <thead>
                                <tr>
                                    <th>@lang('Username')</th>
                                    <th>@lang('Title')</th>
                                    <th>@lang('Url')</th>
                                    <th>@lang('Clicked')</th>
                                    <th>@lang('Type')</th>
                                    <th>@lang('Publication Status') </th>
                                    <th>@lang('Action')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse($ads as $data)
                                    <tr>
                                        <td>
                                            <a href="{{ route('admin.users.detail', $data->user_id) }}">
                                                {{ __(@$data->user->username) }}
                                            </a>
                                        </td>
                                        <td>
                                            {{ strLimit(__($data->title), 40) }}
                                        </td>

                                        <td>
                                            {{ strLimit($data->url, 40) }}
                                        </td>

                                        <td>
                                            {{ $data->clicked }}
                                        </td>

                                        <td>
                                            @if ($data->status == 3)
                                                <span class="badge badge--warning">@lang('Pending')</span>
                                            @elseif($data->status == 4)
                                                <span class="badge badge--warning">@lang('Request For Update')</span>
                                            @endif
                                        </td>

                                        <td>
                                            @if ($data->publication_status == 1)
                                                <span class="badge badge--success">@lang('Published')</span>
                                            @else
                                                <span class="badge badge--danger">@lang('Unublished')</span>
                                            @endif
                                        </td>

                                        <td>
                                            <div class="dropdown">
                                                <button class="btn btn-sm btn-outline--primary" id="actionButton" data-bs-toggle="dropdown">
                                                    <i class="las la-ellipsis-v"></i>@lang('Action')
                                                </button>
                                                <div class="dropdown-menu p-0">
                                                    <a href="javascript:void(0)" class="dropdown-item viewBtn" data-title="{{ $data->title }}" data-click="{{ getAmount($data->click) }}" data-credit="{{ getAmount($data->credit) }}" data-clicked="{{ getAmount($data->clicked) }}" data-url="{{ $data->url }}" data-publish="{{ $data->publication_status }}" data-image="{{ getImage(getFilePath('advertisement') . '/' . $data->image, getFileSize('advertisement')) }}" data-toggle="tooltip" data-original-title="View">
                                                        <i class="las la-eye"></i> @lang('View')
                                                    </a>
                                                    <a href="javascript:void(0)" class="dropdown-item confirmationBtn" data-action="{{ route('admin.ad.approve', $data->id) }}" data-question="@lang('Are you sure to approve this advertisement?')"><i class="las la-check"></i> @lang('Approve')</a>

                                                    <a href="javascript:void(0)" class="dropdown-item confirmationBtn" data-action="{{ route('admin.ad.reject', $data->id) }}" data-question="@lang('Are you sure to reject this advertisement?')"><i class="las la-times"></i> @lang('Reject')</a>

                                                    <a href="javascript:void(0)" class="dropdown-item confirmationBtn" data-action="{{ route('admin.ad.delete', $data->id) }}" data-question="@lang('Are you sure to delete this advertisement?')"><i class="las la-trash-alt"></i> @lang('Delete')</a>
                                                </div>
                                            </div>
                                        </td>
                                    @empty
                                    <tr>
                                        <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                                    </tr>
                                @endforelse

                            </tbody>
                        </table><!-- table end -->
                    </div>
                </div>
                @if ($ads->hasPages())
                    <div class="card-footer py-4">
                        {{ paginateLinks($ads) }}
                    </div>
                @endif
            </div><!-- card end -->
        </div>
    </div>

    {{-- VIEW METHOD MODAL --}}
    <div id="viewModal" class="modal fade" tabindex="-1" role="dialog">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">@lang('View advertisement details')</h5>
                    <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                        <i class="las la-times"></i>
                    </button>
                </div>
                <div class="modal-body">
                    <div class="row">
                        <div class="col-lg-12 form-group">
                            <label for="title">@lang('Title')*</label>
                            <input type="title" value="{{ old('title') }}" readonly name="title" class="form-control" required>
                        </div>
                        <div class="col-lg-12 form-group">
                            <label for="url">@lang('Url')*</label>
                            <input type="url" value="{{ old('url') }}" readonly name="url" class="form-control" required>
                        </div>
                        <div class="col-lg-6 form-group">
                            <label for="click">@lang('Expected click')*</label>
                            <input type="number" name="click" value="{{ old('click') }}" readonly class="form-control" min='1' required>
                        </div>
                        <div class="col-lg-6 form-group">
                            <label for="credit">@lang('Per click credit')*</label>
                            <input type="number" name="credit" value="{{ old('credit') }}" readonly class="form-control" min='1' required>
                        </div>
                        <div class="col-lg-12 form-group">
                            <label for="publication_status">@lang('Publication status')*</label>
                            <input type="text" name="publication_status" class="form-control" readonly="">
                        </div>
                        <div class="col-lg-12">
                            <div class="image-upload">
                                <div class="thumb">
                                    <div class="avatar-preview">
                                        <div class="row">
                                            <div class="col-sm-12">
                                                <x-image-uploader id="update" class="w-100" type="advertisement" :required=false />
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn--dark" data-bs-dismiss="modal">@lang('Close')</button>
                </div>
            </div>
        </div>
    </div>
    <x-confirmation-modal />
@endsection

@push('script')
    <script>
        (function($) {
            "use strict";

            $('.viewBtn').on('click', function() {
                var modal = $('#viewModal');
                modal.find('input[name=title]').val($(this).data('title'));
                modal.find('input[name=url]').val($(this).data('url'));
                modal.find('input[name=click]').val($(this).data('click'));
                modal.find('input[name=credit]').val($(this).data('credit'));
                modal.find('input[name=clicked]').val($(this).data('clicked'));
                modal.find('input[name=duration]').val($(this).data('duration'));
                modal.find('input[name=type]').val($(this).data('type') == 1 ? 'Video' : 'Not Video');
                modal.find('input[name=publication_status]').val($(this).data('publish') == 1 ? 'Published' : 'Unpublished');

                modal.find('.image-upload-preview').css({
                    "background-image": "url(" + $(this).data('image') + ")"
                });
                modal.find('.image-upload-input-wrapper').css({
                    "display": "none"
                });
                modal.modal('show');
            });

        })(jQuery);
    </script>
@endpush

@push('style')
    <style>
        /* Chrome, Safari, Edge, Opera */
        input::-webkit-outer-spin-button,
        input::-webkit-inner-spin-button {
            -webkit-appearance: none;
            margin: 0;
        }

        /* Firefox */
        input[type=number] {
            -moz-appearance: textfield;
        }
    </style>
@endpush
