@extends('admin.layouts.app')

@section('panel')
    <div class="row">

        <div class="col-lg-12">
            <div class="card b-radius--10 ">
                <div class="card-body p-0">

                    <div class="table-responsive--sm table-responsive">
                        <table class="table table--light style--two">

                            <thead>
                                <tr>
                                    <th>@lang('Name')</th>
                                    <th>@lang('Credit')</th>
                                    <th>@lang('Price')</th>
                                    <th>@lang('Sales') </th>
                                    <th>@lang('Featured') </th>
                                    <th>@lang('Status') </th>
                                    <th>@lang('Action')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse($plans as $plan)
                                    <tr>
                                        <td>
                                            {{ __($plan->name) }}
                                        </td>

                                        <td>
                                            {{ getAmount($plan->credit) }}
                                        </td>

                                        <td>
                                            {{ getAmount($plan->price) }}
                                            {{ __(gs()->cur_text) }}
                                        </td>

                                        <td>
                                            <a href="{{ route('admin.purchased.list', ['id' => $plan->id, 'name' => slug($plan->name)]) }}">
                                                <span class="badge badge--primary">{{ getAmount($plan->sold) }}</span>
                                            </a>
                                        </td>

                                        <td>
                                            @if ($plan->featured == 1)
                                                <span class="badge badge--success">@lang('Featured')</span>
                                            @else
                                                <span class="badge badge--warning">@lang('Non-Featured')</span>
                                            @endif
                                        </td>

                                        <td>
                                            @if ($plan->publication_status == 1)
                                                <span class="badge badge--success">@lang('Published')</span>
                                            @else
                                                <span class="badge badge--warning">@lang('Unpublished')</span>
                                            @endif
                                        </td>
                                        <td>
                                            <button type="button" class="btn btn-sm btn-outline--primary editBtn" data-resource="{{ $plan }}"><i class="las la-pencil-alt"></i>@lang('Edit')</button>
                                        </td>
                                    @empty
                                    <tr>
                                        <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                                    </tr>
                                @endforelse

                            </tbody>
                        </table><!-- table end -->
                    </div>
                </div>
                @if ($plans->hasPages())
                    <div class="card-footer py-4">
                        {{ paginateLinks($plans) }}
                    </div>
                @endif
            </div><!-- card end -->
        </div>
    </div>

    {{-- ADDMODAL METHOD MODAL --}}
    <div id="addModal" class="modal fade" tabindex="-1" role="dialog">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">@lang('Add Plan')</h5>
                    <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                        <i class="las la-times"></i>
                    </button>
                </div>
                <form action="{{ route('admin.plan.add') }}" method="POST">
                    @csrf
                    <div class="modal-body">
                        <div class="row">
                            <div class="col-lg-12 form-group">
                                <label for="name">@lang('Name of plan')</label>
                                <input type="text" id="name" value="{{ old('name') }}" name="name" class="form-control" required>
                            </div>
                            <div class="col-lg-6 form-group">
                                <label>@lang('Featured') </label>
                                <input type="checkbox" data-width="100%" data-onstyle="-success" data-offstyle="-danger" data-bs-toggle="toggle" data-on="@lang('Featured')" data-off="@lang('Non-featured')" name="featured">
                            </div>
                            <div class="col-lg-6 form-group">
                                <label>@lang('Publication Status') </label>
                                <input type="checkbox" data-width="100%" data-onstyle="-success" data-offstyle="-danger" data-bs-toggle="toggle" data-on="@lang('Published')" data-off="@lang('Unpublished')" name="publication_status">
                            </div>
                            <div class="col-lg-6 form-group">
                                <label for="price">@lang('Price of plan')</label>
                                <div class="input-group">
                                    <input type="number" step="any" min="0" name="price" value="{{ old('price') }}" id="price" class="form-control" required>
                                    <span class="input-group-text">{{ __(gs()->cur_text) }}</span>
                                </div>
                            </div>
                            <div class="col-lg-6 form-group">
                                <label for="credit">@lang('Credits')</label>
                                <div class="input-group">
                                    <input type="number" name="credit" value="{{ old('credit') }}" id="credit" class="form-control" min='1' required>
                                    <span class="input-group-text">@lang('Credit')</span>
                                </div>
                            </div>

                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn h-45 w-100 btn--primary">@lang('Submit')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    {{-- EDIT METHOD MODAL --}}
    <div id="editModal" class="modal fade" tabindex="-1" role="dialog">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">@lang('Update Plan')</h5>
                    <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                        <i class="las la-times"></i>
                    </button>
                </div>
                <form action="" method="POST">
                    @csrf
                    <input type="hidden" name="id">
                    <div class="modal-body">
                        <div class="row">
                            <div class="col-lg-12 form-group">
                                <label for="name">@lang('Name of plan')</label>
                                <input type="text" name="name" class="form-control" required>
                            </div>
                            <div class="col-lg-6 form-group">
                                <label>@lang('Featured') </label>
                                <input type="checkbox" data-width="100%" data-onstyle="-success" data-offstyle="-danger" data-bs-toggle="toggle" data-on="@lang('Featured')" data-off="@lang('Non-featured')" name="featured">
                            </div>
                            <div class="col-lg-6 form-group">
                                <label>@lang('Publication Status') </label>
                                <input type="checkbox" data-width="100%" data-onstyle="-success" data-offstyle="-danger" data-bs-toggle="toggle" data-on="@lang('Published')" data-off="@lang('Unpublished')" name="publication_status">

                            </div>
                            <div class="col-lg-6 form-group">
                                <label for="price">@lang('Price of plan')</label>
                                <div class="input-group">
                                    <input type="number" step="any" min="0" name="price" class="form-control" required>
                                    <span class="input-group-text">{{ __(gs()->cur_text) }}</span>
                                </div>
                            </div>
                            <div class="col-lg-6 form-group">
                                <label for="credit">@lang('Credits')</label>
                                <div class="input-group">
                                    <input type="number" name="credit" class="form-control" min='1' required>
                                    <span class="input-group-text">@lang('Credit')</span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn--primary h-45 w-100">@lang('Submit')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection

@push('breadcrumb-plugins')
    <button type="button" class="btn btn-outline--primary btn-sm" data-bs-toggle="modal" data-bs-target="#addModal"><i class="las la-plus"></i>@lang('Add New')</button>
@endpush

@push('script')
    <script>
        (function($) {
            "use strict";

            $('.editBtn').on('click', function() {
                let modal = $('#editModal');
                let resource = $(this).data('resource');
                let url = "{{ route('admin.plan.add', ':id') }}".replace(':id', resource.id);

                modal.find('input[name=name]').val(resource.name);
                modal.find('input[name=price]').val(resource.price);
                modal.find('input[name=credit]').val(resource.credit);
                modal.find('input[name=featured]').bootstrapToggle(resource.featured == 1 ? 'on' : 'off')
                modal.find('input[name=publication_status]').bootstrapToggle(resource.publication_status == 1 ? 'on' : 'off');
                modal.find('form').attr('action', url);
                modal.modal('show');
            });

        })(jQuery);
    </script>
@endpush

@push('style')
    <style>
        input::-webkit-outer-spin-button,
        input::-webkit-inner-spin-button {
            -webkit-appearance: none;
            margin: 0;
        }

        input[type=number] {
            -moz-appearance: textfield;
        }
    </style>
@endpush
