@extends('Template::layouts.app')

@php
    $bgImage = getContent('backgroundImage.content', true);
@endphp

@section('panel')
    <section class="account--section bg_img bg--overlay pb-80 pt-80" data-background="{{ getImage('assets/images/frontend/backgroundImage/' . @$bgImage->data_values->image, '1920x1080') }}">
        <div class="container">
            <div class="row justify-content-center">
                <div class="col-xl-6">
                    <div class="card contact-wrapper bg--glass px-0 pt-0">
                        <div class="logo mt-4">
                            <a href="{{ route('home') }}"><img src="{{ siteLogo() }}" alt="logo"></a>
                        </div>
                        <h5 class="m-0 py-3 card-header text-white text-center">@lang('Verify Mobile Number')</h5>

                        <div class="card-body">

                            <div class="d-flex justify-content-center">
                                <div class="verification-code-wrapper">
                                    <div class="verification-area">
                                        <form action="{{ route('user.verify.mobile') }}" method="POST" class="login-form submit-form">
                                            @csrf
                                            <p class="verification-text">@lang('A 6 digit verification code sent to your mobile number') : +{{ showMobileNumber(auth()->user()->mobileNumber) }}</p>

                                            @include('Template::partials.verification_code')

                                            <div class="mb-3">
                                                <button type="submit" class="cmn--btn w-100">@lang('Submit')</button>
                                            </div>

                                            <div>
                                                <p class="verification-info mb-0">
                                                    @lang('If you don\'t get any code'), <span class="countdown-wrapper">@lang('try again after') <span id="countdown" class="fw-bold">--</span> @lang('seconds')</span> <a href="{{ route('user.send.verify.code', 'sms') }}" class="try-again-link d-none"> @lang('Try again')</a>
                                                </p>
                                                <a href="{{ route('user.logout') }}">@lang('Logout')</a>
                                            </div>
                                        </form>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
@endsection

@push('style')
    <style>
        .verification-code-wrapper {
            background-color: #042656;
            border-color: #346dff4d;
        }

        .verification-area h5 {
            color: #fff;
            border-bottom-color: rgba(255, 255, 255, 0.15) !important;
        }

        .verification-area .verification-text {
            color: rgba(255, 255, 255, 0.8);
            margin-top: 8px;
        }

        .verification-area .verification-info {
            color: rgba(255, 255, 255, 0.6);
            margin-top: 0px;
        }

        .verification-area .form-label {
            color: rgba(255, 255, 255, 0.8);
        }

        .verification-code::after {
            background-color: #042656;
        }

        .verification-code span {
            color: #fff;
            background: transparent;
            border-radius: 3px;
            border-color: rgba(255, 255, 255, 0.15);
        }

        .verification-code input {
            color: #fff !important;
        }
    </style>
@endpush

@push('script')
    <script>
        var distance = Number("{{ @$user->ver_code_send_at->addMinutes(2)->timestamp - time() }}");
        var x = setInterval(function() {
            distance--;
            document.getElementById("countdown").innerHTML = distance;
            if (distance <= 0) {
                clearInterval(x);
                document.querySelector('.countdown-wrapper').classList.add('d-none');
                document.querySelector('.try-again-link').classList.remove('d-none');
            }
        }, 1000);
    </script>
@endpush
