@extends('Template::layouts.master')
@section('content')
    <section class="dashboard-section pt-80">
        <div class="container">
            <div class="pb-80">
                <div class="profile-wrapper bg--shadow">
                    <div class="profile-form-area w-100 p-0">
                        <form class="profile-edit-form" action="{{ route('user.promotion.confirm') }}" method="post" enctype="multipart/form-data">
                            @csrf
                            <div class="row gy-4">
                                <div class="col-md-6">
                                    <label class="custom--label text--title required" for="title">@lang('Title') <span class="text--danger">*</span></label>
                                    <input type="text" class="form-control form--control" value="{{ old('title') }}" id="title" name="title" required>
                                </div>
                                <div class="col-md-6">
                                    <label class="custom--label text--title" for="url">@lang('URL') <span class="text--danger">*</span></label>
                                    <input type="text" class="form-control form--control" value="{{ old('url') }}" id="url" name="url" required>
                                </div>
                                <div class="col-md-6">
                                    <label class="custom--label text--title" for="click">@lang('Expected Click') <span class="text--danger">*</span></label>
                                    <input type="number" class="form-control form--control" name="click" id="click" min="1" value="{{ old('click') }}" required>
                                </div>
                                <div class="col-md-6">
                                    <label class="custom--label text--title" for="city">@lang('Per Click Credit')
                                        (@lang('Minimum required '){{ getAmount(gs()->min_credit) }}) <span class="text--danger">*</span>
                                    </label>
                                    <input type="number" min="{{ getAmount(gs()->min_credit) }}" class="form-control form--control" name="credit" value="{{ old('credit') }}" id="credit" required>
                                </div>

                                <div class="col-md-12">
                                    <label class="custom--label text--title" for="email">@lang('Publication Status') <span class="text--danger">*</span></label>
                                    <select name="publication_status" id="publication_status" class="form-control form--control w-100 minimal select2" data-minimum-results-for-search="-1" required>
                                        <option value="">@lang('Select One')</option>
                                        <option value="1" @selected(old('publication_status') == 1)>@lang('Published')</option>
                                        <option value="0" @selected(old('publication_status') === 0)>@lang('Unpublished')</option>
                                    </select>
                                </div>
                                <div class="col-md-6">
                                    <div class="image-upload">
                                        <div class="thumb">
                                            <div class="avatar-preview">
                                                <div class="row">
                                                    <div class="col-sm-12">
                                                        <div class="profilePicPreview" id="display_image">
                                                            <span class="size_mention"></span>
                                                            <button type="button" id="image_remove_id" class="remove-image"><i class="fa fa-times"></i></button>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="avatar-edit">
                                                <input type="file" class="profilePicUpload" id="profilePicUpload1" accept=".png, .jpg, .jpeg" name="image">
                                                <label for="profilePicUpload1" id='image_btn' class="btn btn-primary">@lang('Select Image') </label>
                                                <span class="custom--label text--title">@lang('Supported image .jpeg, .png, .jpg, 300x250')</span>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-md-12">
                                    <button type="submit" class="w-100 cmn--btn">@lang('Submit')</button>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </section>
@endsection

@push('style')
    <link rel="stylesheet" href="{{ asset($activeTemplateTrue . '/css/promotion.css') }}">
    <style>
        .profile-edit-form button[type="submit"] {
            padding-top: 17px;
            padding-bottom: 17px;
        }

        .select2-container--default .select2-selection--single {
            background-color: #f1f5f8;
            border-width: 1px !important;
            border-color: rgba(4, 38, 86, 0.2) !important;
            padding: 14px 16px !important;
        }

        .select2-container--focus .select2-selection.select2-selection--single,
        .select2-container--focus .select2-selection.select2-selection--multiple {
            outline: none !important;
            box-shadow: none !important;
            background-color: transparent;
            border-color: rgba(30, 144, 255, 0.2) !important;
        }

        .select2-container--open .select2-selection.select2-selection--single,
        .select2-container--open .select2-selection.select2-selection--multiple {
            border-color: rgba(30, 144, 255, 0.2) !important;
        }

        .select2-container--default .select2-selection--single .select2-selection__arrow {
            top: 16px !important;
        }
    </style>
@endpush

@push('script')
    <script>
        (function($) {

            "use strict";

            $('#display_image').hide();

            $('#image_btn').on('click', function() {
                var classNmae = $('#display_image').attr('class');

                if (classNmae != 'profilePicPreview has-image') {
                    $('#display_image').hide();
                } else {
                    $('#display_image').show();
                }

            });

            $('#image_remove_id').on('click', function() {
                $('#display_image').hide();
            });

            function proPicURL(input) {
                if (input.files && input.files[0]) {
                    var reader = new FileReader();
                    reader.onload = function(e) {
                        var preview = $(input).parents('.thumb').find('.profilePicPreview');
                        $(preview).css('background-image', 'url(' + e.target.result + ')');
                        $(preview).addClass('has-image');
                        $(preview).hide();
                        $(preview).fadeIn(650);
                    }
                    reader.readAsDataURL(input.files[0]);
                }
            }

            $(".profilePicUpload").on('change', function() {
                proPicURL(this);
            });

            $(".remove-image").on('click', function() {
                $(this).parents(".profilePicPreview").css('background-image', 'none');
                $(this).parents(".profilePicPreview").removeClass('has-image');
                $(this).parents(".thumb").find('input[type=file]').val('');
            });

            $("form").on("change", ".file-upload-field", function() {
                $(this).parent(".file-upload-wrapper").attr("data-text", $(this).val().replace(/.*(\/|\\)/, ''));
            });


        })(jQuery);
    </script>
@endpush
