@extends('Template::layouts.master')

@section('content')
    <!-- Dashboard -->
    <section class="dashboard-section pt-80">
        <div class="container">

            <div class="pb-80">
                <div class="message__chatbox bg--shadow">
                    <div class="message__chatbox__header">
                        <h5 class="title">@lang('Create New Support')</h5>
                        <a href="{{ route('ticket.index') }}" class="cmn--btn btn--sm">@lang('My Supports')</a>
                    </div>
                    <div class="message__chatbox__body">
                        <form action="{{ route('ticket.store') }}" class="disableSubmission" method="post" enctype="multipart/form-data">
                            @csrf
                            <div class="row">
                                <div class="form-group form--group col-md-6">
                                    <label class="form-label custom--label text--title">@lang('Subject')</label>
                                    <input type="text" name="subject" value="{{ old('subject') }}" class="form-control form--control" required>
                                </div>
                                <div class="form-group form--group col-md-6">
                                    <label class="form-label custom--label text--title">@lang('Priority')</label>
                                    <select name="priority" class="form-control form--control select2" data-minimum-results-for-search="-1" required>
                                        <option value="3">@lang('High')</option>
                                        <option value="2">@lang('Medium')</option>
                                        <option value="1">@lang('Low')</option>
                                    </select>
                                </div>
                                <div class="col-12 form-group form--group">
                                    <label class="form-label custom--label text--title">@lang('Message')</label>
                                    <textarea name="message" id="inputMessage" rows="6" class="form-control form--control" required>{{ old('message') }}</textarea>
                                </div>

                                <div class="col-md-9">
                                    <button type="button" class="btn btn-dark btn-sm addAttachment my-2"> <i class="fas fa-plus"></i> @lang('Add Attachment') </button>
                                    <p class="mb-2"><span class="text--info">@lang('Max 5 files can be uploaded | Maximum upload size is ' . convertToReadableSize(ini_get('upload_max_filesize')) . ' | Allowed File Extensions: .jpg, .jpeg, .png, .pdf, .doc, .docx')</span></p>
                                    <div class="row fileUploadsContainer">
                                    </div>
                                </div>
                                <div class="col-md-3">
                                    <button class="cmn--btn w-100 justify-content-center" type="submit"><i class="las la-paper-plane"></i> @lang('Submit')
                                    </button>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            </div>

        </div>
    </section>
    <!-- Dashboard -->
@endsection

@push('style')
    <style>
        .select2-container {
            width: 100% !important;
        }

        .select2-container--default .select2-selection--single {
            background-color: #f1f5f8;
            border-width: 1px !important;
            border-color: rgba(4, 38, 86, 0.2) !important;
            padding: 14px 16px !important;
        }

        .select2-container--focus .select2-selection.select2-selection--single,
        .select2-container--focus .select2-selection.select2-selection--multiple {
            outline: none !important;
            box-shadow: none !important;
            background-color: transparent;
            border-color: rgba(30, 144, 255, 0.2) !important;
        }

        .select2-container--open .select2-selection.select2-selection--single,
        .select2-container--open .select2-selection.select2-selection--multiple {
            border-color: rgba(30, 144, 255, 0.2) !important;
        }

        .select2-container--default .select2-selection--single .select2-selection__arrow {
            top: 16px !important;
        }
    </style>
@endpush

@push('script')
    <script>
        (function($) {
            "use strict";
            var fileAdded = 0;
            $('.addAttachment').on('click', function() {
                fileAdded++;
                if (fileAdded == 5) {
                    $(this).attr('disabled', true)
                }
                $(".fileUploadsContainer").append(`
                    <div class="col-lg-6 col-md-12 removeFileInput">
                        <div class="form-group form--group">
                            <div class="input-group">
                                <input type="file" name="attachments[]" class="form-control form--control" accept=".jpeg,.jpg,.png,.pdf,.doc,.docx" required>
                                <button type="button" class="input-group-text removeFile bg--danger text-white border-0"><i class="fas fa-times"></i></button>
                            </div>
                        </div>
                    </div>
                `)
            });
            $(document).on('click', '.removeFile', function() {
                $('.addAttachment').removeAttr('disabled', true)
                fileAdded--;
                $(this).closest('.removeFileInput').remove();
            });
        })(jQuery);
    </script>
@endpush
