@extends('Template::layouts.master')
@section('content')
    <section class="dashboard-section pt-80">
        <div class="container">

            <div class="row justify-content-center pb-80">
                <div class="col-md-12">
                    <div class="show-filter mb-3 text-end">
                        <button type="button" class="btn btn--base showFilterBtn btn-sm"><i class="las la-filter"></i> @lang('Filter')</button>
                    </div>
                    <div class="card responsive-filter-card mb-4">
                        <div class="card-body">
                            <form class="d-flex flex-wrap gap-4">
                                <div class="flex-grow-1">
                                    <label class="form-label">@lang('Transaction Number')</label>
                                    <input type="search" name="search" value="{{ request()->search }}" class="form-control form--control">
                                </div>
                                <div class="flex-grow-1">
                                    <label class="form-label">@lang('Type')</label>
                                    <select name="trx_type" class="form-control form--control select2" data-minimum-results-for-search="-1">
                                        <option value="">@lang('All')</option>
                                        <option value="+" @selected(request()->trx_type == '+')>@lang('Plus')</option>
                                        <option value="-" @selected(request()->trx_type == '-')>@lang('Minus')</option>
                                    </select>
                                </div>
                                <div class="flex-grow-1">
                                    <label class="form-label">@lang('Remark')</label>
                                    <select class="form-control form--control select2" data-minimum-results-for-search="-1" name="remark">
                                        <option value="" selected>@lang('All')</option>
                                        @foreach ($remarks as $remark)
                                            <option value="{{ $remark->remark }}" @selected(request()->remark == $remark->remark)>{{ __(keyToTitle($remark->remark)) }}</option>
                                        @endforeach
                                    </select>
                                </div>
                                <div class="flex-grow-1">
                                    <div class="d-flex align-items-end  h-100">
                                        <button class="cmn--btn w-100">
                                            <i class="las la-filter"></i>
                                            @lang('Filter')
                                        </button>
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>

                    <div class="table-responsive">
                        <table class="table cmn--table">
                            <thead>
                                <tr>
                                    <th>@lang('Trx')</th>
                                    <th>@lang('Transacted')</th>
                                    <th>@lang('Amount')</th>
                                    <th>@lang('Post Balance')</th>
                                    <th>@lang('Detail')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse($transactions as $trx)
                                    <tr>
                                        <td>{{ $trx->trx }}</td>

                                        <td>
                                            {{ showDateTime($trx->created_at) }}<br>{{ diffForHumans($trx->created_at) }}
                                        </td>

                                        <td>
                                            <span class="fw-bold @if ($trx->trx_type == '+') text--success @else text--danger @endif">
                                                {{ $trx->trx_type }} {{ showAmount($trx->amount) }}
                                            </span>
                                        </td>

                                        <td>
                                            {{ showAmount($trx->post_balance) }}
                                        </td>

                                        <td>{{ __($trx->details) }}</td>
                                    </tr>
                                @empty
                                    <tr>
                                        <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                                    </tr>
                                @endforelse
                            </tbody>
                        </table>
                    </div>

                    @if ($transactions->hasPages())
                        <div class="card-footer">
                            {{ paginateLinks($transactions) }}
                        </div>
                    @endif

                </div>
            </div>

        </div>
    </section>
@endsection

@push('style')
    <style>
        .responsive-filter-card {
            border: 1px solid #e5e5e5 !important;
        }

        .responsive-filter-card .cmn--btn {
            height: calc(100% - 34px);
            margin-bottom: 2px;
        }

        .select2-container {
            width: 100% !important;
        }

        .select2-container--default .select2-selection--single {
            background-color: #f1f5f8;
            border-width: 1px !important;
            border-color: rgba(4, 38, 86, 0.2) !important;
            padding: 14px 16px !important;
        }

        .select2-container--focus .select2-selection.select2-selection--single,
        .select2-container--focus .select2-selection.select2-selection--multiple {
            outline: none !important;
            box-shadow: none !important;
            background-color: transparent;
            border-color: rgba(30, 144, 255, 0.2) !important;
        }

        .select2-container--open .select2-selection.select2-selection--single,
        .select2-container--open .select2-selection.select2-selection--multiple {
            border-color: rgba(30, 144, 255, 0.2) !important;
        }

        .select2-container--default .select2-selection--single .select2-selection__arrow {
            top: 16px !important;
        }
    </style>
@endpush
